@@ -87,7 +87,10 @@ class PyXploraApi(PyXplora):
         return self._setDevices(ids)
 
     def _setDevices(self, ids: list = []) -> List[str]:
-        wuids: List[str] = self.getWatchUserIDs(ids)
+        if ids:
+            wuids = ids
+        else:
+            wuids: List[str] = self.getWatchUserIDs()
         for wuid in wuids:
             self.device[wuid] = {}
             self.device[wuid]["getWatchAlarm"] = self.getWatchAlarm(wuid=wuid)
